@@ -12,8 +12,8 @@
 #include <glib-object.h>
 #include "ppd-profile.h"
 
-#define PPD_TYPE_ACTION (ppd_action_get_type())
-G_DECLARE_DERIVABLE_TYPE(PpdAction, ppd_action, PPD, ACTION, GObject)
+#define PPD_TYPE_ACTION (ppd_action_get_type ())
+G_DECLARE_DERIVABLE_TYPE (PpdAction, ppd_action, PPD, ACTION, GObject)
 
 /**
  * PpdActionClass:
@@ -28,14 +28,14 @@ struct _PpdActionClass
 {
   GObjectClass   parent_class;
 
-  gboolean       (* probe)            (PpdAction  *action);
+  PpdProbeResult (* probe)            (PpdAction  *action);
   gboolean       (* activate_profile) (PpdAction  *action,
                                        PpdProfile  profile,
                                        GError    **error);
 };
 
 #ifndef __GTK_DOC_IGNORE__
-gboolean ppd_action_probe (PpdAction *action);
+PpdProbeResult ppd_action_probe (PpdAction *action);
 gboolean ppd_action_activate_profile (PpdAction *action, PpdProfile profile, GError **error);
 const char *ppd_action_get_action_name (PpdAction *action);
 #endif
